#
# spec file for package rehex
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rehex
Version:        0.4.1
Release:        bp156.2.6
Summary:        Reverse Engineers' Hex Editor
License:        GPL-2.0-only
URL:            https://github.com/solemnwarning/rehex
Source0:        https://github.com/solemnwarning/rehex/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libunistring-devel
BuildRequires:  update-desktop-files
%if 0%{?suse_version} > 1500
BuildRequires:  wxWidgets-3_0-devel
%else
BuildRequires:  wxWidgets-devel
%endif
BuildRequires:  (pkgconfig(lua5.3) or pkgconfig(lua))
BuildRequires:  pkgconfig(capstone)
BuildRequires:  pkgconfig(jansson)

%description
A hex heditor with a number of features for analysing and annotating
binary file formats.

Current features include:

    Large file support (tested up to 1 TiB)
    Decoding of integer/floating point value types
    Disassembly of machine code
    Highlighting and annotation of ranges of bytes

%prep
%autosetup
dos2unix README.md

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="$CFLAGS"
%make_build prefix=%{_prefix} libdir=%{_libdir}

%install
%make_install prefix=%{_prefix} libdir=%{_libdir}
%suse_update_desktop_file -r %{name} "Development;Debugger;"

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Fri Jan  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1:
  * Fix text rendering glitches that can occur when displaying
    control characters and some Unicode ones, depending which font
    is in use (worst affected is the default Windows font).
* Fri Jan  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  * Add data types for common text encodings (Unicode, ISO-8859)
    text displayed or typed into the text view on the right will
    be decoded or encoded appropriately (#10).
  * Treat pasted text as text rather than a string of raw bytes.
  * Add 8-bit integer data types.
  * Don't mark new files as unsaved.
  * Store cursor position history and allow jumping backwards/forwards (#81).
  * Allow jumping to previous/next difference in data compare window (#131).
  * Collapse long ranges of identical data in data compare window (#85).
  * Added "Jump to offset in main window" to data compare window context menu.
  * Added shortcuts for comparing data (#103).
  * Add support for other encodings to strings tool (#106).
  * Add write protect flag to prevent accidental changes to file
    data during analysis (#130).
  * Respect system cursor blink speed setting (#112).
* Thu Aug 26 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.3.92:
  * Reduce persistent memory usage (#52).
  * Fully undo virtual mapping changes in one step (#126).
  * Fix build dependency errors (#129).
  * Add "Find previous" button to search dialogs (#111).
  * Fix hard-to-see colours in "Decode values" panel on some
    systems (#127).
  * Fix build errors on FreeBSD (#133).
  * Prevent document from jumping around when the window is resized
    or disassembly is in progress (#132).
  * Fix build errors when using wxWidgets 3.1.5 and newer.
  * Refactor selection handling to make sense in virtual
    section view (#125).
  * Add font face setting to "View" menu (#128).
  * Correctly track whether files have been modified
    since saving (#122).
* Thu Jun 24 2021 Luigi Baldoni <aloisio@gmx.com>
- Fix Factory build
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.3.91
  * Show disassembly of machine code in the main document view
  * Add float/double types to "Set data type" menu
  * Initial support for Lua plugins.
  * Process sections from PE EXE/DLL headers
  * Virtual segment mapping and display
- Use optflags
* Fri Nov 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.3.1 (2020-11-13)
  * Correctly display signed 16-bit values in "Decode values" panel.
  * Fix status bar offset going out of sync.
  * Move cursor when a row in the "Comments" panel is double clicked.
  * Focus document after updating position/selection via "Comments"
    panel.
* Wed Nov 11 2020 Luigi Baldoni <aloisio@gmx.com>
  Version 0.3.0 (2020-11-10)
  * Use byte grouping setting from main window in diff window.
  * Use Capstone disassembler rather than LLVM.
  * Support disassembling 16-bit x86 machine code.
  * Don't update tools which aren't visible.
  * Unhardcode linux launcher icon file type.
  * Fix an uncommon use-after-free crash when closing tabs in
    diff window.
  * Support for disassembling 6800/68000 and MOS6502 instruction
    sets (requires recent Capstone version).
  * Close document when tab is clicked with middle mouse button.
  * Don't create .rehex-meta files when there is nothing to save.
  * Implement Strings tool to find and list ASCII strings in the
    file.
  * Add option to calculate automatic bytes per line in whole
    byte groups.
  * Add "Fill range" tool for overwriting ranges of bytes with a
    pattern.
  * Preserve column alignment after comments.
  * Mark a document dirty if highlighting is changed.
  * Add data type annotations.
  * Show ranges marked as integers in their decoded form in the
    hex view.
  * Performance improvements for documents with large numbers of
    comments.
  version 0.2.0:
  * Allow copying comments from a document and pasting them
    elsewhere in the same document or into another one.
  * Fixed bounds check when clicking on nested comments in a
    document.
  * Added context menu when right clicking on a comment in a
    document.
  * Optionally highlight byte sequences which match the current
    selection. ("Highlight data matching selection" or
    "PatternMatchHighlight").
  * Allow copying cursor offset from document context menu.
  * Correctly display offsets over 4GiB in the status bar.
  * Display offsets as XXXX:XXXX rather than XXXXXXXX:XXXXXXXX
    when the file size is under 4GiB.
  * Add per-document option for dec/hex offset display.
  * When first byte after a comment is deleted, show that the
    comment was deleted rather than leaving phantom comment on
    screen until regions are repopulated.
  * Add side-by-side comparison of chunks of data from files.
    Select data and choose "Compare..." from context menu to
    open diff window.
  * Clean up search threads when a tab is closed while a search
    is running.
  * Display bytes which have been modified since the file was
    saved in red.
* Fri Mar 13 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.1.0)
